;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "helm" "4.0.7"
  "Helm is an Emacs incremental and narrowing framework."
  '((helm-core "4.0.7")
    (wfnames   "1.2"))
  :url "https://emacs-helm.github.io/helm/"
  :commit "3cd5097285dc10ac0898cf6f30c9699c3399e421"
  :revdesc "v4.0.7-0-g3cd5097285dc"
  :keywords '("helm" "convenience" "files" "buffers" "grep" "completion" "lisp" "matching" "tools" "help")
  :authors '(("Thierry Volpiatto" . "thievol@posteo.net"))
  :maintainers '(("Thierry Volpiatto" . "thievol@posteo.net")))
